# When bootstrapping new Python we need to build flit in bootstrap mode.
# The Python RPM dependency generators and pip are not yet available.
%bcond_with bootstrap

# Tests are enabled by default, unless we bootstrap.
# Disable them to avoid a circular build dependency on testpath.
%bcond_with tests

Name:           python-flit-core
Version:        3.11.0
Release:        %mkrel 1
Summary:        PEP 517 build backend for packages using Flit
Group:          Development/Other
# flit-core is BSD-3-Clause
# flit_core/versionno.py contains a regex that is from packaging, BSD-2-Clause
License:        BSD-3-Clause AND BSD-2-Clause

URL:            https://flit.pypa.io/
Source:         %{pypi_source flit_core}
Patch:          0001-Fix-build-without-bundled-tomli.patch

BuildArch:      noarch
BuildRequires:  python3-devel

%if %{with tests}
BuildRequires:  python3-pytest
# Test deps that require flit-core to build:
BuildRequires:  python3-testpath
%endif

%global _description %{expand:
This provides a PEP 517 build backend for packages using Flit.
The only public interface is the API specified by PEP 517,
at flit_core.buildapi.}

%description %_description


%package -n python3-flit-core
Summary:        %{summary}
Conflicts:      python3-flit < 2.1.0-2

# RPM generators are not yet available when we bootstrap
%if %{with bootstrap}
Provides:       python%{python3_pkgversion}dist(flit-core) = %{version}
Provides:       python%{python3_version}dist(flit-core) = %{version}
Requires:       python(abi) = %{python3_version}
%endif

%description -n python3-flit-core %_description


%prep
%autosetup -p1 -n flit_core-%{version}

# Remove vendored tomli that flit_core includes to solve the circular dependency on older Pythons
# (flit_core requires tomli, but flit_core is needed to build tomli).
# We don't use this, as tomllib is a part of standard library since Python 3.11.
rm -rf flit_core/vendor


%if %{without bootstrap}
%generate_buildrequires
%pyproject_buildrequires
%endif


%build
%if %{with bootstrap}
%{python3} -m flit_core.wheel
%else
%pyproject_wheel
%endif

%install
%if %{with bootstrap}
%{python3} bootstrap_install.py --install-root %{buildroot} dist/flit_core-%{version}-py3-none-any.whl
# for consistency with %%pyproject_install:
rm %{buildroot}%{python3_sitelib}/flit_core-*.dist-info/RECORD
%else
%pyproject_install
%endif

%check
%py3_check_import flit_core flit_core.buildapi
%if %{with tests}
%pytest
%endif


%files -n python3-flit-core
%license LICENSE
%doc README.rst
%{python3_sitelib}/flit_core-*.dist-info/
%{python3_sitelib}/flit_core/


%changelog
* Fri Feb 21 2025 wally <wally> 3.11.0-1.mga10
+ Revision: 2150606
- new version 3.11.0

* Thu Feb 20 2025 wally <wally> 3.9.0-4.mga10
+ Revision: 2150135
- bootstrap build for python3.13

* Thu Dec 28 2023 papoteur <papoteur> 3.9.0-3.mga10
+ Revision: 2023017
- rebuild without bootstrap and with tests

* Thu Dec 07 2023 wally <wally> 3.9.0-2.mga10
+ Revision: 2014412
- bootstrap build for py3.12 update

* Sun Nov 26 2023 wally <wally> 3.9.0-1.mga10
+ Revision: 2009789
- split out from python-flit
- new version 3.9.0
- sync .spec with Fedora

* Wed Nov 30 2022 papoteur <papoteur> 3.8.0-2.mga9
+ Revision: 1913549
- new 3.8.0
+ wally <wally>
- sync with Fedora where appropriate

* Mon Apr 04 2022 guillomovitch <guillomovitch> 3.7.1-1.mga9
+ Revision: 1843881
- new version 3.7.1

* Tue Mar 29 2022 umeabot <umeabot> 3.6.0-3.mga9
+ Revision: 1832173
- Mageia 9 Mass Rebuild

* Sun Feb 20 2022 mrambo3501 <mrambo3501> 3.6.0-2.mga9
+ Revision: 1781636
- rebuild for python-3.10

* Sun Feb 06 2022 wally <wally> 3.6.0-1.mga9
+ Revision: 1771922
- new version 3.6.0
- rebuild for python3.10

* Sat Aug 28 2021 wally <wally> 3.3.0-1.mga9
+ Revision: 1743272
- new version 3.3.0

* Mon Mar 15 2021 wally <wally> 3.1.0-1.mga9
+ Revision: 1703500
- new version 3.1.0
- rebuild for python 3.9

* Sat Nov 14 2020 guillomovitch <guillomovitch> 3.0.0-1.mga8
+ Revision: 1646151
- new version 3.0.0

* Tue Jun 09 2020 daviddavid <daviddavid> 2.3.0-1.mga8
+ Revision: 1591159
- new version: 2.3.0

* Thu Feb 20 2020 umeabot <umeabot> 2.2.0-2.mga8
+ Revision: 1546111
- Mageia 8 Mass Rebuild

* Fri Jan 31 2020 daviddavid <daviddavid> 2.2.0-1.mga8
+ Revision: 1485939
- new version: 2.2.0

* Sat Dec 14 2019 daviddavid <daviddavid> 2.1.0-2.mga8
+ Revision: 1467109
- properly package flit-core and restore /usr/bin/flit (#1783610)

* Thu Dec 12 2019 daviddavid <daviddavid> 2.1.0-1.mga8
+ Revision: 1466064
- new version: 2.1.0

* Fri Sep 06 2019 wally <wally> 1.3-2.mga8
+ Revision: 1437998
- rebuild for python3.8

* Fri Apr 19 2019 wally <wally> 1.3-1.mga7
+ Revision: 1393412
- new version 1.3

* Tue Jan 08 2019 tv <tv> 0.11.4-3.mga7
+ Revision: 1352058
- rebuild with python 3.7

* Thu Sep 20 2018 umeabot <umeabot> 0.11.4-2.mga7
+ Revision: 1288906
- Mageia 7 Mass Rebuild

* Tue Aug 15 2017 philippem <philippem> 0.11.4-1.mga7
+ Revision: 1140806
- add group
- imported package python-flit

